"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.FirebaseFirestoreSnapshot = exports.FirebaseFirestoreCollection = exports.FirebaseFirestoreDocument = void 0;
const Flattable_1 = require("./../utils/Flattable");
const firestore_1 = require("firebase/firestore");
class FirebaseFirestoreDocument {
    options;
    path;
    firestoreInstance;
    constructor(options, path, firestoreInstance) {
        this.options = options;
        this.path = path;
        this.firestoreInstance = firestoreInstance;
    }
    getSubCollection(key) {
        return new FirebaseFirestoreCollection(this.options, this.path.appending(key), this.firestoreInstance);
    }
    async setValues(values) {
        await (0, firestore_1.setDoc)((0, firestore_1.doc)(this.firestoreInstance, this.path.fullPath), Flattable_1.Flattable.flatten(values));
    }
    async snapshot() {
        const snapshot = await (0, firestore_1.getDoc)((0, firestore_1.doc)(this.firestoreInstance, this.path.fullPath));
        return new FirebaseFirestoreSnapshot(this.options, snapshot);
    }
}
exports.FirebaseFirestoreDocument = FirebaseFirestoreDocument;
class FirebaseFirestoreCollection {
    options;
    path;
    firestoreInstance;
    constructor(options, path, firestoreInstance) {
        this.options = options;
        this.path = path;
        this.firestoreInstance = firestoreInstance;
    }
    async addDocument(key, documentValues) {
        await (0, firestore_1.setDoc)((0, firestore_1.doc)(this.firestoreInstance, this.path.appending(key).fullPath), Flattable_1.Flattable.flatten(documentValues));
    }
    getDocument(key) {
        return new FirebaseFirestoreDocument(this.options, this.path.appending(key), this.firestoreInstance);
    }
    async removeDocument(key) {
        await (0, firestore_1.deleteDoc)((0, firestore_1.doc)(this.firestoreInstance, this.path.appending(key).fullPath));
    }
}
exports.FirebaseFirestoreCollection = FirebaseFirestoreCollection;
class FirebaseFirestoreSnapshot {
    options;
    snapshot;
    constructor(options, snapshot) {
        this.options = options;
        this.snapshot = snapshot;
    }
    get exists() {
        return this.snapshot.exists();
    }
    get data() {
        // eslint-disable-next-line @typescript-eslint/no-non-null-assertion
        return this.snapshot.data();
    }
}
exports.FirebaseFirestoreSnapshot = FirebaseFirestoreSnapshot;
